@@ -5,7 +5,7 @@ def cotizaAuto(token, **data):
     url = constantes.API+'/api/v1/cotizacion/cotizar'
     headers = {'Accept':'application/json','Authorization':'Bearer '+token}
 
-    response = requests.post(url, json=data, headers=headers)
+    response = requests.post(url, json=data, headers=headers, timeout=10)
 
     if response.status_code == 200:
         response_json = json.loads(response.text)
