@@ -5,7 +5,7 @@ def getEmision(token, **data):
     url = constantes.API+'/api/v1/emision'
     headers = {'Accept':'application/json','Authorization':'Bearer '+token}
 
-    response = requests.post(url, json=data, headers=headers)
+    response = requests.post(url, json=data, headers=headers, timeout=10)
 
     if response.status_code == 200:
         response_json = json.loads(response.text)
@@ -20,7 +20,7 @@ def getPoliza(token, **data):
     url = constantes.API+'/api/v1/emision/imprime/poliza'
     headers = {'Accept':'application/json','Authorization':'Bearer '+token}
 
-    response = requests.post(url, json=data, headers=headers)
+    response = requests.post(url, json=data, headers=headers, timeout=10)
 
     if response.status_code == 200:
         response_json = json.loads(response.text)
