@@ -5,7 +5,7 @@ def getLogin(user, pase):
     url = constantes.API+'/api/v1/usuario/login'
     headers = {'Content-Type': 'application/json'}
     args = {'username':user,'password':pase}
-    response = requests.post(url, json=args, headers=headers)
+    response = requests.post(url, json=args, headers=headers, timeout=10)
 
     if response.status_code == 200:
         response_json = json.loads(response.text)
@@ -22,7 +22,7 @@ def regUsuario(**data):
     url = constantes.API+'/api/v1/usuario/crear'
     headers = headers = {'Content-Type': 'application/json'}
 
-    response = requests.post(url, json=data, headers=headers)
+    response = requests.post(url, json=data, headers=headers, timeout=10)
 
     if response.status_code == 200:
         response_json = json.loads(response.text)
@@ -39,7 +39,7 @@ def insertaClaves(token, **data):
     url = constantes.API+'/api/v1/usuario/save/claveagente'
     headers = {'Accept':'application/json','Authorization':'Bearer '+token}
 
-    response = requests.post(url, json=data, headers=headers)
+    response = requests.post(url, json=data, headers=headers, timeout=10)
 
     if response.status_code == 200:
         response_json = json.loads(response.text)
