@@ -5,7 +5,7 @@ def getEdades(token):
     url = constantes.API+'/api/v1/cotizacion/edad'
     headers = {'Accept':'application/json','Authorization':'Bearer '+token}
 
-    response = requests.get(url, headers=headers)
+    response = requests.get(url, headers=headers, timeout=10)
 
     if response.status_code == 200:
         response_json = json.loads(response.text)
